@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # <sure - utility belt for automated testing in python>
-# Copyright (C) <2010-2012>  Gabriel Falcão <gabriel@nacaolivre.org>
+# Copyright (C) <2010-2013>  Gabriel Falcão <gabriel@nacaolivre.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -41,7 +41,29 @@ from sure.registry import context as _registry
 from sure.six import string_types, text_type, PY3, get_function_code
 from sure.six.moves import reduce
 
-version = '1.1.6'
+
+def safely_patch_dir(object_handler):
+    def custom_dir(self):
+        if not PY3:
+            try:
+                meta = list(self.__dict__)
+            except AttributeError:
+                meta = list(type(self).__dict__)
+
+            object_attrs = set(meta)
+        else:
+            object_attrs = set(super().__dir__())
+
+        sure_methods = set(POSITIVES + NEGATIVES)
+        return list(object_attrs.difference(sure_methods))
+
+    object_handler['__dir__'] = custom_dir
+
+
+if PY3:
+    basestring = str
+
+version = '1.2.0'
 
 
 not_here_error = \
@@ -50,6 +72,9 @@ not_here_error = \
     'Maybe you misspelled it ? Well, here are the options: %s'
 
 
+original_obj_attrs = dir(object)
+
+
 class VariablesBag(dict):
     __varnames__ = None
     __sure_actions_ran__ = None
@@ -798,31 +823,34 @@ class AssertionBuilder(object):
     def match(self, regex, *args):
         obj_repr = repr(self.obj)
         assert isinstance(self.obj, basestring), (
-            "{} should be a string in order to compare using .match()".format(obj_repr)
+            "{0} should be a string in order to compare using .match()".format(obj_repr)
         )
         matched = re.search(regex, self.obj, *args)
 
-        modifiers = "{}{}{}{}{}".format(
-            re.I in args and "i" or "",
-            re.L in args and "l" or "",
-            re.M in args and "m" or "",
-            re.S in args and "s" or "",
-            re.U in args and "u" or "",
-        )
-        regex_representation = '/{}/{}'.format(regex, modifiers)
+        modifiers_map = {
+            re.I: "i",
+            re.L: "l",
+            re.M: "m",
+            re.S: "s",
+            re.U: "u",
+        }
+        modifiers = "".join([modifiers_map.get(x, "") for x in args])
+        regex_representation = '/{0}/{1}'.format(regex, modifiers)
+
         if self.negative:
             assert matched is None, (
-                "{} should not match the regular expression {}".format(
+                "{0} should not match the regular expression {1}".format(
                     obj_repr, regex_representation))
 
         else:
             assert matched is not None, (
-                "{} doesn't match the regular expression {}".format(
+                "{0} doesn't match the regular expression {1}".format(
                     obj_repr, regex_representation))
 
         return True
 
 this = AssertionBuilder('this')
+the = AssertionBuilder('the')
 it = AssertionBuilder('it')
 these = AssertionBuilder('these')
 those = AssertionBuilder('those')
@@ -880,10 +908,11 @@ if is_cpython and allows_new_syntax:
         return make_safe_property(method, name, prop)
 
     object_handler = patchable_builtin(object)
-
+    safely_patch_dir(object_handler)
     # None does not have a tp_dict associated to its PyObject, so this
     # is the only way we could make it work like we expected.
     none = patchable_builtin(None.__class__)
+
     for name in POSITIVES:
         object_handler[name] = positive_assertion(name)
         none[name] = positive_assertion(name, False)
